from setuptools import setup

setup(name='distributionsVeer',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['distributionsVeer'],
      author = 'Veeru Talreja',
      zip_safe=False)
